jQuery plugin: Tablesorter 2.0 - Enabling debug mode

# tablesorter

## Dealing with digits

### Flexible client-side table sorting

Back to documentation

# Demo

First Name | Last Name | Age | Total | Discount | Diff
--- | --- | --- | --- | --- | ---
Peter | Parker | 28 | 9.99 | 20.3% | +3.0
John | Hood | 33 | 19.99 | 25.1% | -7
Clark | Kent | 18 | 15.89 | 44.2% | -15
Bruce | Almighty | 45 | 153.19 | 44% | +19
Bruce | Evans | 56 | 153.19 | 23% | +9

# Javascript

# HTML